@@ -2,7 +2,7 @@
 saltfactories.utils.compat
 ~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-Imports compatability layer
+Compatibility layer
 """
 
 
@@ -10,7 +10,7 @@ def has_unittest_attr(item, attr):
     """
     Check if a test item has a specific attribute set.
 
-    This is basically a compatability layer while Salt migrates to PyTest
+    This is basically a compatibility layer while Salt migrates to PyTest
     """
     if hasattr(item.obj, attr):
         return True
