@@ -26,9 +26,7 @@ def test_run_expensive_skipped(testdir):
         from _pytest.outcomes import Failed
 
         with pytest.raises(Failed):
-            res.stdout.fnmatch_lines(
-                ["*PytestUnknownMarkWarning*",]
-            )
+            res.stdout.fnmatch_lines(["*PytestUnknownMarkWarning*"])
 
 
 def test_run_expensive_not_skipped(testdir):
@@ -50,6 +48,4 @@ def test_run_expensive_not_skipped(testdir):
         from _pytest.outcomes import Failed
 
         with pytest.raises(Failed):
-            res.stdout.fnmatch_lines(
-                ["*PytestUnknownMarkWarning*",]
-            )
+            res.stdout.fnmatch_lines(["*PytestUnknownMarkWarning*"])
