@@ -38,9 +38,7 @@ def test_skipped(testdir, platform):
         from _pytest.outcomes import Failed
 
         with pytest.raises(Failed):
-            res.stdout.fnmatch_lines(
-                ["*PytestUnknownMarkWarning*",]
-            )
+            res.stdout.fnmatch_lines(["*PytestUnknownMarkWarning*"])
 
 
 @pytest.mark.parametrize(
@@ -72,9 +70,7 @@ def test_not_skipped(testdir, platform):
         from _pytest.outcomes import Failed
 
         with pytest.raises(Failed):
-            res.stdout.fnmatch_lines(
-                ["*PytestUnknownMarkWarning*",]
-            )
+            res.stdout.fnmatch_lines(["*PytestUnknownMarkWarning*"])
 
 
 def test_skip_reason(testdir):
