@@ -5,7 +5,7 @@ from saltfactories.utils import random_string
 
 @pytest.fixture(scope="module")
 def master(salt_factories):
-    factory = salt_factories.get_salt_master_daemon("master-1")
+    factory = salt_factories.get_salt_master_daemon(random_string("master-"))
     with factory.started():
         yield factory
 
@@ -34,6 +34,19 @@ def test_minion(minion, salt_cli):
     assert ret.json is True
 
 
+def test_multiple_start_stops(master):
+    factory = master.get_salt_minion_daemon(random_string("minion-"))
+    assert factory.is_running() is False
+    pid = None
+    with factory.started():
+        assert factory.is_running() is True
+        pid = factory.pid
+    assert factory.is_running() is False
+    with factory.started():
+        assert factory.is_running() is True
+        assert factory.pid != pid
+
+
 def test_no_match(minion, salt_cli):
     assert minion.is_running()
     ret = salt_cli.run("test.ping", minion_tgt="minion-2")
