@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
     tests.unit.utils.markers.test_skip_if_no_remote_network
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -6,8 +5,7 @@
     Test the "skip_if_no_remote_network" marker helper
 """
 import socket
-
-import mock
+from unittest import mock
 
 import saltfactories.utils.markers as markers
 
